#!/bin/bash

# check if the reboot flag file exists. 
if [ ! -f /home/pi/resume-after-reboot ]; then
    echo ""
    echo ""
    echo ""
    echo "This script will automate the installation process for reef-pi but does require attending."
    echo "During the installation the Raspberry Pi will reboot, following this restart the SSH terminal again so the installation process can be completed."

    echo ""
    echo "During the install you will be prompted for your timezone"
    echo ""
    echo "Visit https://en.wikipedia.org/wiki/List_of_tz_database_time_zones for a list of timezones"
    echo ""
    echo "The name from 'TZ database name' column needs to be typed in exactly or you will receive an error."

    echo ""
    echo ""
    echo "This script does the following"
    echo "    * updates Raspbian"
    echo "    * expands file system on microSD card"
    echo "    * prompts for time zone"
    echo "    * enables time sync"
    echo "    * enables I2C"
    echo "    * sets I2C speed to 10 kHz"
    echo "    * disables SPI"
    echo "    * enables 1-wire"
    echo "    * enables PWM on Raspberry Pi pin GPIO12 and GPIO13 "
    echo "    * installs reef-pi"
    echo "    * generates website address to access reef-pi"
    echo ""

    echo ""
    echo ""
    echo "Press enter to continue or press Ctrl + Z to abort"
    read input
    echo "Setting up the Raspberry Pi"

    # # # install i2ctools
    sudo apt-get install i2c-tools

    # # # expand file system
    sudo raspi-config --expand-rootfs

    # # Add script to system startup file so script can continue after reboot
    script="bash /boot/install_reefpi.sh"
    echo "$script" >> ~/.bashrc
    
    # # create a flag file to check if we are resuming from reboot.
    sudo touch /home/pi/resume-after-reboot
    
    echo ""
    echo ""
    echo ""
    echo ""
    echo ""
    echo "The Raspberry Pi needs to reboot now."
    echo "Your terminal window will close."
    echo ""
    echo "Wait 30-60 seconds for the Raspberry Pi to restart, then open this terminal window again."
    echo "When you log back into the SSH terminal the installation will continue."
    echo ""
    echo ""
    echo ""
    echo "Press enter to continue"
    echo ""
    read input
    echo "rebooting..."
    sudo reboot
  
else 
    echo ""
    echo ""
    echo ""
    echo ""
    echo "Resuming reef-pi installation..."
    echo ""
    echo ""
    
    # Remove the line that we added in zshrc
    sed -i '/bash/d' ~/.bashrc 
    
    # remove the temporary file that we created to check for reboot
    sudo rm -f /home/pi/resume-after-reboot

    # update timezone
    echo "Enter your Timezone and press enter - visit https://en.wikipedia.org/wiki/List_of_tz_database_time_zones for a list of time zone names"
    read timez
    echo "You set your timezone to " $timez
    sudo timedatectl set-timezone $timez

    # # update Raspbian
    sudo apt update
    sudo apt full-upgrade

    # # sync time
    sudo systemctl start systemd-timesyncd
    sudo systemctl enable systemd-timesyncd

    ################################## Edit config.txt file ##############################################
    # # replace word in file
    sudo sed -i 's/dtparam=i2c_arm=off/dtparam=i2c_arm=on/g' /boot/config.txt
    sudo sed -i 's/#dtparam=i2c_arm=on/dtparam=i2c_arm=on/g' /boot/config.txt
    sudo sed -i 's/dtparam=spi=on/dtparam=spi=off/g' /boot/config.txt


    # # add line after search
    sudo sed -i '/dtparam=spi=off/a dtparam=i2c_arm_baudrate=10000' /boot/config.txt
    sudo sed -i '/dtparam=i2c_arm_baudrate=10000/a #dtoverlay=w1-gpio' /boot/config.txt

    # # replace word in file
    sudo sed -i 's/#dtoverlay=w1-gpio/dtoverlay=w1-gpio/g' /boot/config.txt

    # # add line after search
    sudo sed -i '/dtoverlay=w1-gpio/a dtoverlay=pwm-2chan' /boot/config.txt

    # # install reef-pi
    echo ""
    echo ""
    echo ""
    echo ""
    echo ""
    echo "reef-pi will be installed now, enter a numebr from list for the Raspberry Pi you use and press enter"
    echo "1 = Raspberry Pi Zero W"
    echo "2 = Raspberry Pi 3 or Pi 4"
    echo ""
    read pi
    if [ $pi = 1 ] 
    then
        rasp="Raspberry Pi Zero W"
    else
        rasp="Raspberry Pi 3 or Pi 4"
    fi

    echo "You are installing reef-pi on a" $rasp
    
    if [ $pi = 1 ] 
    then
        wget -c https://github.com/reef-pi/reef-pi/releases/download/3.4/reef-pi-3.4-pi0.deb
        sudo dpkg -i reef-pi-3.4-pi0.deb
    else
        wget -c https://github.com/reef-pi/reef-pi/releases/download/3.4/reef-pi-3.4-pi3.deb
        sudo dpkg -i reef-pi-3.4-pi3.deb
    fi

    echo ""
    echo ""
    echo ""
    echo ""
    echo ""
    echo "reef-pi has been installed!"
    echo ""
    echo "If you didn't receive any errors during the process you should be set and can close this window."
    echo ""
    echo "Open a web browser from a device on your network and type in the following address to open reef-pi"
    echo ""
    ip= hostname -I | awk '{ print "http://" $1 }'
    echo ""
    echo ""

    echo "The default login for reef-pi is as follows."
    echo ""
    echo "Username = reef-pi"
    echo "Password = reef-pi"
    echo ""
    echo ""
    echo ""
    echo "Have a great day!"
    echo ""
fi